| tapnet2df | R Documentation |
Function allows direct use of data prepared for tapnet analysis by other statistical methods, e.g. regression approaches
tapnet2df(tapnetObject)
tapnetObject |
results of applying fit_tapnet to the tapnet object; |
This function simply puts all data into a data.frame, with each row an entry in the network matrix.
A data.frame containing network observations, PEMs, traits and abundances for regression-type analysis.
Carsten Dormann <carsten.dormann@biom.uni-freiburg.de>
Benadi et al. in prep
ex <- simulate_tapnet(nlower=10, nhigher=50, ntraits_pem=3, ntraits_nopem=2, Nwebs = 3)
df <- tapnet2df(ex)
head(df)
## Not run:
library(ranger)
frf <- ranger(interactions ~ ., data=df[, -c(1:2)], importance="impurity")
sort(importance(frf), decreasing=TRUE)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.